@@ -41,7 +41,7 @@
 	}
 </script>
 		
-<form action="index.php?amn=grp_edit" method="post" name="frm" id="id_frm">
+<form action="index.php?amn=grp_edit" method="post" name="frm" id="id_frm" enctype="multipart/form-data">
 <input type="hidden" name="group_id" value="<?php if (isset($group['group_id'])) { echo $group['group_id'];}?>" />
 
 <?php
@@ -56,16 +56,51 @@ if (isset($display) && $display == "policy") {
 	
 	<div class="box_mid">
 		<div class="content">
-			<p>
-				<label for="id_group_policy"><?php echo $lang['txt_policy'];?></label>
-				<textarea id="id_group_policy" name="group_policy" cols="72" rows="16"><?php if (isset($group['group_policy'])) { echo $group['group_policy'];}?></textarea>
-				<br />
-			</p>
+			<table cellspacing="1" cellpadding="0" border="0" width="100%">
+				<tr>
+					<td>
+						<b><label for="id_group_policy" style="width:300px"><?php echo $lang['txt_title_policy'];?></label></b><br />
+					</td>
+					<td>
+						<?php
+						$gui_expert_editor = "id_group_policy";
+						include($template_path_core . "inc/form_gui_html_editor.inc.php");
+						?>
+					</td>
+				</tr>
+			</table>
+				
+			<table cellspacing="1" cellpadding="0" border="0" width="100%">
+				<tr>
+					<td width="1">
+						<textarea id="id_group_policy" name="group_policy" cols="72" rows="8" style="width:480px;" onKeyUp="AMEditorSync(this.value, 'wysiwyg_editor');"><?php if (isset($group['group_policy'])) { echo $group['group_policy'];}?></textarea>
+						<br />
+					</td>
+					<td>
+						<br />
+					</td>
+					<td rowspan="2" valign="top" width="90%">
+						<div id="editor_help"><?php echo $lang['txt_help_default'];?></div>
+					</td>
+				</tr>
+				<tr>
+					<td width="1">
+						<iframe id="wysiwyg_editor" name="wysiwyg_editor" style="height:100px; width:480px;" frameborder="0" width="580"  scrolling="yes"  height="100">
 			
-			<?php
-			$txtarea = "id_group_policy";
-			include($template_path_core . "inc/form_gui_html_editor.inc.php");
-			?>
+						</iframe>
+					</td>
+					<td valign="top" width="20">
+						<img src="<?php echo $template_path_core;?>img/arrow_up.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize();" /><br />
+						<img src="<?php echo $template_path_core;?>img/arrow_down.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize('minus');" /><br />
+						<img src="<?php echo $template_path_core;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
+					</td>
+				</tr>
+			</table>
+			
+			<script language="javascript" type="text/javascript">
+				var wysiwygHeight = 100;
+				var thisEditor = new AMEditor('id_group_policy', 'wysiwyg_editor');
+			</script>
 			
 			<hr />
 			
@@ -106,23 +141,28 @@ else {
 	
 	<div class="box_mid">
 		<div class="content">
+			<p>
+				<b><?php echo $lang['txt_title_intro'];?></b><br />
+			</p>
+			
+			<p>
+				<label for="id_group_title"><?php echo $lang['txt_title'];?></label>
+				<input id="id_group_title" class="input" type="text" name="group_title" size="24" style="width:480px;" value="<?php if (isset($group['group_title'])) { echo $group['group_title'];}?>" />
+				&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
+				<br />
+			</p>
+
+			<p>
+				<label for="id_group_synopsis"><?php echo $lang['txt_synopsis'];?></label>
+				<textarea id="id_group_synopsis" name="group_synopsis" cols="22" style="width:480px;" rows="2"><?php if (isset($group['group_synopsis'])) { echo $group['group_synopsis'];}?></textarea>
+				<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
+				<br />
+			</p>
+
+
 			<table cellspacing="0" cellpadding="0" border="0">
 				<tr>
 					<td valign="top" width="50%">
-						<p>
-							<label for="id_group_title"><?php echo $lang['txt_title'];?></label>
-							<input id="id_group_title" class="input" type="text" name="group_title" size="24" value="<?php if (isset($group['group_title'])) { echo $group['group_title'];}?>" />
-							&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
-							<br />
-						</p>
-						
-						<p>
-							<label for="id_group_synopsis"><?php echo $lang['txt_synopsis'];?></label>
-							<textarea id="id_group_synopsis" name="group_synopsis" cols="22" rows="2"><?php if (isset($group['group_synopsis'])) { echo $group['group_synopsis'];}?></textarea>
-							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
-							<br />
-						</p>
-						
 						<p>
 							<label for="id_network"><?php echo $lang['txt_age'];?></label>
 							<?php
@@ -183,42 +223,6 @@ else {
 						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" /><br />
 					</td>
 					<td valign="top" width="50%">
-						<?php
-						if (isset($images)) {
-						?>
-						<table cellspacing="0" cellpadding="2" border="0" width="100%">
-							<tr>
-								<td valign="top">
-									<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />	
-								</td>
-								<td valign="top" width="100%">
-									<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
-										<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
-										<?php
-										$img_divs = "";
-										foreach($images as $key => $i):
-										$display_state = "none";
-										$selected = "";
-										if (isset($group['file_id']) && $group['file_id'] == $i['file_id']) {
-											$selected = "selected=\"selected\"";
-											$display_state = "block";
-										}
-										?>
-										<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
-										<?php
-										$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
-										endforeach;
-										?>
-									</select>
-								</td>
-								<td valign="top" align="right">
-									<?php echo $img_divs;?>
-								</td>	
-							</tr>
-						</table>
-						<?php }?>
-						
-				
 						<script type="text/javascript">
 						function showMembershipTypes(id) {
 							var displaystate = 'none';
@@ -281,11 +285,11 @@ else {
 							<?php
 							if (isset($lang['membership_type'])) {
 							foreach ($lang['membership_type'] as $key => $i):
-								
+	
 							$selected = "";
 							
-							if (!empty($set['membership_type_ids'])) {					
-								foreach ($set['membership_type_ids'] as $keymt => $mt):
+							if (!empty($group['membership_type_ids'])) { 
+								foreach ($group['membership_type_ids'] as $keymt => $mt):
 									if ($mt['membership_type_id'] == $key) {
 										$selected = "checked=\"checked\"";
 										break;
@@ -376,20 +380,111 @@ else {
 			</table>
 			
 			<hr />
-			
+
 			<p>
-				<label for="id_group_body"><?php echo $lang['txt_body'];?></label>
-				<textarea id="id_group_body" name="group_body" cols="82" rows="6" style="width: 480px;"><?php if (isset($group['group_body'])) { echo $group['group_body'];}?></textarea>
-				<br />
+				<b><?php echo $lang['txt_title_create'];?></b><br />
 			</p>
 			
-			<?php
-			$txtarea = "id_group_body";
-			include($template_path_core . "inc/form_gui_html_editor.inc.php");
-			?>
-
+			<table cellspacing="1" cellpadding="0" border="0" width="100%">
+				<tr>
+					<td>
+						<label for="id_subject_body"><?php echo $lang['txt_body'];?></label><br />
+					</td>
+					<td>
+						<?php
+						$gui_expert_editor = "id_subject_body";
+						include($template_path_core . "inc/form_gui_html_editor.inc.php");
+						?>
+					</td>
+				</tr>
+			</table>
+				
+			<table cellspacing="1" cellpadding="0" border="0" width="100%">
+				<tr>
+					<td width="1">
+						<textarea id="id_group_body" name="group_body" cols="72" rows="8" style="width:480px;" onKeyUp="AMEditorSync(this.value, 'wysiwyg_editor');"><?php if (isset($group['group_body'])) { echo $group['group_body'];}?></textarea>
+				<br />
+					</td>
+					<td>
+						<br />
+					</td>
+					<td rowspan="2" valign="top" width="90%">
+						<div id="editor_help"><?php echo $lang['txt_help_default'];?></div>
+					</td>
+				</tr>
+				<tr>
+					<td width="1">
+						<iframe id="wysiwyg_editor" name="wysiwyg_editor" style="height:100px; width:480px;" frameborder="0" width="580"  scrolling="yes"  height="100">
+			
+						</iframe>
+					</td>
+					<td valign="top" width="20">
+						<img src="<?php echo $template_path_core;?>img/arrow_up.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize();" /><br />
+						<img src="<?php echo $template_path_core;?>img/arrow_down.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize('minus');" /><br />
+						<img src="<?php echo $template_path_core;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
+					</td>
+				</tr>
+			</table>
+			
+			<script language="javascript" type="text/javascript">
+				var wysiwygHeight = 100;
+				var thisEditor = new AMEditor('id_group_body', 'wysiwyg_editor');
+			</script>
+			
 			<hr />
 			
+			<p>
+				<b><?php echo $lang['txt_title_image'];?></b><br />
+			</p>
+
+			<?php
+			if (isset($images)) {
+			?>
+			<div style="overflow: auto; width:710px;">
+			<table cellspacing="0" cellpadding="2" border="0">
+			<tr>
+				<td valign="top" align="center">
+					<?php echo $lang['txt_none'];?><br />
+					<input type="radio" name="file_id" value="0" checked="checked" /><br />
+					<img src="<?php echo $template_path_core;?>img/pixel.png" width="60" height="1" alt="" border="0" /><br />
+				</td>
+				<?php
+				foreach($images as $i):
+				$selected = "";
+				if (isset($group['file_id']) && $group['file_id'] == $i['file_id']) {
+					$selected = "checked=\"checked\"";
+				}
+				?>
+				<td valign="top" align="center">
+					<img class="picture" src="get_file.php?file=<?php echo $i['file_md5_name_view']; ?>" alt="<?php echo $i['file_save_name']; ?>"/><br />
+					<input type="radio" name="file_id" value="<?php echo $i['file_id'];?>" <?php echo $selected;?> /><br />
+				</td>
+				<?php
+				endforeach;
+				?>
+			</tr>
+			</table>
+			</div>
+			<?php }?>
+			
+			<br />
+
+			<p>
+				<label for="frm_file"><?php echo $lang['txt_file_to_upload']; ?></label>
+				<input type="file" name="frm_file" id="frm_file" class="input1" /><br />
+			</p>
+
+			<p>
+				<label for="frm_file_name"><?php echo $lang['txt_file_to_upload_name']; ?></label>
+				<input type="text" name="frm_file_name" class="input1" id="frm_file_name" value="<?php echo isset($_REQUEST['update'], $selected_file[0]['file_save_name']) ? $selected_file[0]['file_save_name'] : ''; ?>"/>
+			</p>
+			
+			<hr />
+			
+			<p>
+				<b><?php echo $lang['txt_title_save'];?></b><br />
+			</p>
+			
 			<p align="right">
 				<input type="submit" name="preview_group" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
 				<?php
